@@ -471,11 +471,10 @@ magnifier_expose_filter (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 static void
 magnifier_set_extension_listeners (Magnifier *magnifier, GdkWindow *root)
 {
-	g_message ("adding expose listener on root");
-	/* TODO: remove listener from 'old' root if one was already present */	
-	gdk_window_add_filter (root, magnifier_expose_filter, NULL);
-	magnifier_damage_client_init (magnifier);
-	magnifier_cursor_notification_init (magnifier);
+	if (!magnifier_damage_client_init (magnifier))
+	    g_warning ("Damage client hooks were not initialized.");
+	if (!magnifier_cursor_notification_init (magnifier))
+	    g_warning ("Cursor change notification hooks were not initialized.");
 }
 
 static void
